@@ -53,8 +53,8 @@ QUERY2;
 
 $query3 = <<< QUERY3
 update $table_name 
-	set res_number="{$res_number}" 
-	where record_type=1 and 
+	set res_number="{$res_number}" , record_type=1 
+	where (record_type=1 or record_type=4) and 
 		board_name="{$board_name}" and 
 		dat_name='{$dat_name}' 
 QUERY3;
