@@ -152,7 +152,7 @@ BOOL nt_read_thread(nt_2ch_selected_item_handle h_select)
 	wchar_t *server_name, *board_name;
 	nt_board_tp boardp;
 	nt_thread_tp threadp;
-	int len;
+	int len, res_no;
 	iconv_t icd;
 	FILE	*fp_src;
 	char	s_src[S_SIZE*sizeof(wchar_t)];
@@ -262,7 +262,9 @@ BOOL nt_read_thread(nt_2ch_selected_item_handle h_select)
 	}
 	nt_thread_clear_children(&threadp->handle);
 	threadp->num_res = 0;
+	res_no = 0;
 	while(1){
+		res_no++;
 		if(feof(fp_src))
 			break;
 		s_src[0] = '\0';
@@ -282,7 +284,7 @@ BOOL nt_read_thread(nt_2ch_selected_item_handle h_select)
 		}
 		*((wchar_t*)p_dst) = L'\0';
 		if(!is_matchi_bbs)
-			parse_thread(&threadp->handle, (const wchar_t*)s_dst);
+			parse_thread(&threadp->handle, (const wchar_t*)s_dst, res_no);
 		else
 			parse_thread_machi_bbs(&threadp->handle, (const wchar_t*)s_dst);
 	}
