@@ -256,7 +256,7 @@ static BOOL nt_cloud_edit_lines_file_async(nt_cloud_handle handle,
 		free(cptr);
 		return FALSE;
 	}
-	if(NULL == nt_link_add_data(param, php_file)){
+	if(NULL == nt_link_add_data(param, (void*)php_file)){
 		nt_all_link_free(param, NULL);
 		free(cptr);
 		return FALSE;
