@@ -121,6 +121,12 @@ extern char *MARU_PW;
 #define NT_COMMAND1_UPLOAD_BOARD2 "b"
 #define NT_COMMAND1_UPLOAD_THREAD1 "thread"
 #define NT_COMMAND1_UPLOAD_THREAD2 "t"
+#define NT_COMMAND1_EDIT_FAVORITE_1 "edit"
+#define NT_COMMAND1_EDIT_FAVORITE_2 "e"
+#define NT_COMMAND1_EDIT_FAVORITE_BOARD1 "board"
+#define NT_COMMAND1_EDIT_FAVORITE_BOARD2 "b"
+#define NT_COMMAND1_EDIT_FAVORITE_THREAD1 "thread"
+#define NT_COMMAND1_EDIT_FAVORITE_THREAD2 "t"
 #define NT_COMMAND1_UPLOAD_NG_FILE1 "ng"
 #define NT_COMMAND1_UPLOAD_NG_FILE2 "n"
 #define NT_COMMAND1_LIMIT_1 "limit"
