@@ -66,6 +66,8 @@
 #define DISP_CMD_EDIT_NGNAME (15*256)
 #define DISP_CMD_EDIT_NGID (16*256)
 #define DISP_CMD_UPLOAD_NG_FILES (17*256)
+#define DISP_CMD_EDIT_FAVORITE_BOARD (18*256)
+#define DISP_CMD_EDIT_FAVORITE_THREAD (19*256)
 
 
 extern int disp_board_menu(nt_window_tp wp, 
