@@ -46,12 +46,14 @@ extern void favorite_dump(nt_favorite_handle handle);
 
 extern BOOL nt_favorite_load_boards(
 			nt_favorite_handle handle, nt_link_tp board_list);
-extern nt_link_tp nt_favorite_retrieve_boards(nt_favorite_handle handle);
 extern BOOL nt_favorite_load_threads(nt_favorite_handle handle, 
 		nt_favorite_grp_handle h_grp, 
 		nt_link_tp thread_list);
+extern nt_link_tp nt_favorite_retrieve_boards(nt_favorite_handle handle);
 extern BOOL nt_favorite_retrieve_threads(nt_favorite_handle handle,
 		nt_link_tp *grp_list, nt_link_tp *thread_list);
+extern BOOL nt_favorite_retrieve_thread(nt_favorite_thread_handle h_thread, 
+		nt_link_tp *thread_list);
 
 extern nt_favorite_handle nt_favorite_alloc(const wchar_t *unique_key);
 extern nt_favorite_board_handle nt_favorite_board_alloc(
