@@ -96,6 +96,10 @@ int main(int argc, char *argv[])
 	sleep(1);
 
 
+	nt_timer_lib_init();
+	
+	nt_mutex_lib_init();
+	
 	usr_db_handle = nt_usr_db_init_lib(USR_LOG_DB_PATH);
 	if(!usr_db_handle){
 		fputs("Couldn't initialize usr database.\n", stderr);
@@ -110,10 +114,6 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	nt_timer_lib_init();
-	
-	nt_mutex_lib_init();
-	
 	if(!nt_pthread_lib_init(
 			NT_PTHREAD_POOL_SIZE, 
 			NT_PTHREAD_POOL_QUEUE_SIZE, 
@@ -644,31 +644,56 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				}
 			}
 			h_searched_thread = NULL;
-			disp_state = disp_thread_search(search_winp, 
+			state = disp_thread_search(search_winp, 
 					state, linkp, &h_searched_thread);
 			ch = NT_KEY_NONE;
 			if(h_searched_thread){
-				if(nt_set_sel_item(app_2ch_model,
-						&h_sel_items_tmp, h_searched_thread, &status_msg)){
-					disp_state = DISP_STATE_RESLIST;
-					nt_2ch_selected_item_release_ref(h_sel_items);
-					h_sel_items = h_sel_items_tmp;
-					if(rwinp->data){
-						free_reslist_ctx(rwinp->data);
-						rwinp->data = NULL;
+				if(DISP_CMD(state) == DISP_CMD_SEL_THREAD){
+					if(nt_set_sel_item(app_2ch_model,
+							&h_sel_items_tmp, h_searched_thread, &status_msg)){
+						disp_state = DISP_STATE_RESLIST;
+						nt_2ch_selected_item_release_ref(h_sel_items);
+						h_sel_items = h_sel_items_tmp;
+						if(rwinp->data){
+							free_reslist_ctx(rwinp->data);
+							rwinp->data = NULL;
+						}
+						if(twinp->data){
+							free_threadlist_ctx(twinp->data);
+							twinp->data = NULL;
+						}
+						nt_searched_thread_release_ref(h_searched_thread);
+						h_searched_thread = NULL;
+						continue;
 					}
-					if(twinp->data){
-						free_threadlist_ctx(twinp->data);
-						twinp->data = NULL;
+				}else if(DISP_CMD(state) == DISP_CMD_ADD_FAVORITE){
+					h_favorite_thread = nt_favorite_thread_alloc(
+						h_favorite_grp,
+						nt_searched_thread_get_dat_name(h_searched_thread),
+						nt_searched_thread_get_board_name(h_searched_thread),
+						nt_searched_thread_get_title(h_searched_thread));
+					if(h_favorite_thread){
+						linkp = NULL;
+						if(nt_favorite_retrieve_thread(h_favorite_thread, &linkp)){
+							if(h_cloud)
+								nt_cloud_insert_lines_into_file(h_cloud, "ft.txt", linkp);
+							nt_all_link_free(linkp, free);
+						}
+						nt_favorite_thread_release_ref(h_favorite_thread);
+						status_msg = NT_INFO_ADD_FAVORITE_SUCCEEDED;
+					}else{
+						status_msg = NT_ERR_MSG_ADD_FAVORITE_FAILED;
 					}
+					disp_state = state = DISP_STATE_SEARCH_THREAD;
 					nt_searched_thread_release_ref(h_searched_thread);
 					h_searched_thread = NULL;
 					continue;
 				}
 				nt_searched_thread_release_ref(h_searched_thread);
 				h_searched_thread = NULL;
-			}
-			if(disp_state != DISP_STATE_SEARCH_THREAD){
+				disp_state = state = DISP_STATE_SEARCH_THREAD;
+			}else if(state != DISP_STATE_SEARCH_THREAD){
+				disp_state = state;
 				continue;
 			}
 			break;
@@ -724,6 +749,7 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 			}
 			if(state != DISP_STATE_HISTORY){
 				disp_state = state;
+				state = DISP_STATE_HISTORY;
 				ch = NT_KEY_NONE;
 				continue;
 			}
@@ -801,6 +827,52 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}
 					nt_searched_thread_release_ref(h_searched_thread);
 					h_searched_thread = NULL;
+				}else if(DISP_CMD(state) == DISP_CMD_EDIT_FAVORITE_BOARD ||
+						DISP_CMD(state) == DISP_CMD_EDIT_FAVORITE_THREAD){
+					ch = NT_KEY_NONE;
+					if(DISP_CMD(state) == DISP_CMD_EDIT_FAVORITE_BOARD){
+						linkp = nt_favorite_retrieve_boards(h_favorite);
+					}else{
+						if(nt_favorite_retrieve_threads(h_favorite, 
+								&linkp2, &linkp)){
+							if(linkp2)
+								nt_all_link_free(linkp2, free);
+						}
+					}
+					if(!linkp)
+						break;
+					linkp = disp_editor3(linkp);
+					if(!linkp){
+						break;
+					}
+					
+					if(DISP_CMD(state) == DISP_CMD_EDIT_FAVORITE_BOARD){
+						if(nt_favorite_load_boards(h_favorite, linkp)){
+							if(favorite_winp->data){
+								free_favorite_ctx(favorite_winp->data);
+								favorite_winp->data = NULL;
+							}
+						}
+						if(h_cloud){
+							nt_cloud_upload_file(h_cloud, "fb.txt", linkp);
+						}
+					}else{
+						if(nt_favorite_load_threads(h_favorite, h_favorite_grp, linkp)){
+							if(favorite_winp->data){
+								free_favorite_ctx(favorite_winp->data);
+								favorite_winp->data = NULL;
+							}
+						}
+						if(h_cloud){
+							nt_cloud_upload_file(h_cloud, "ft.txt", linkp);
+						}
+					}
+					nt_all_link_free(linkp, free);
+					DISP_CLR_CMD(state);
+					keypad(stdscr, true);
+					status_msg = NT_INFO_REFRESH_FAVORITE_SUCCESS;
+					wclear(scrp);
+					continue;
 				}else if(DISP_CMD(state) == DISP_CMD_REFRESH){
 					state = DISP_STATE_FAVORITE;
 					ch = NT_KEY_NONE;
