@@ -226,7 +226,7 @@ int nt_http_post2(const char *url, const char *post_data,
 			}else if(IS_SET_FLAG(responsep, CHUNKED_FLAG)){
 				p3 = p1 = out_buf;
 				while(0 < (nread = strtol(p1, &p2, 16))){
-					memcpy(p3, p2+2, nread);
+					memmove(p3, p2+2, nread);
 					p3 += nread;
 					p1 = p2 + nread + 4;
 				}
@@ -559,13 +559,38 @@ static nt_http_header_tp nt_http_init_header(const char *url)
 		host[len] = '\0';
 	}
 
+#ifdef NT_NET_IPV6
+	if(nt_is_ipv6_addr(host, &cptr)){
+		if(!ssl){
+			*cptr = '\0';
+			cptr++;
+			memmove(host, host+1, cptr - host);
+		}else{
+			cptr++;
+		}
+		if(*cptr == ':'){
+			port = atoi(cptr+1);
+			port = (port == 0) ? -1 : port;
+			*cptr = '\0';
+		}
+		port = atoi(cptr);
+		port = (port == 0) ? -1 : port;
+	}else{
+		cptr = strchr(host, ':');
+		if(cptr != NULL && strlen(cptr+1) > 0){
+			port = atoi(cptr+1);
+			port = (port == 0) ? -1 : port;
+			*cptr = '\0';
+		}
+	}
+#else
 	cptr = strrchr(host, ':');
 	if(cptr != NULL && strlen(cptr) > 0){
 		port = atoi(cptr);
 		port = (port == 0) ? -1 : port;
 		*cptr = '\0';
 	}
-
+#endif
 	headerp = calloc(1, sizeof(nt_http_header_t));
 	if(headerp == NULL){
 		free(host);
