@@ -35,6 +35,7 @@
 #define NT_CMD_NONE 0
 #define NT_CMD_SEARCH_THREAD 1
 #define NT_CMD_FAVORITE 2
+#define NT_CMD_HISTORY 3
 
 
 typedef struct tag_category_data_t *category_data_tp;
@@ -146,6 +147,8 @@ int disp_board_menu(nt_window_tp wp,
 			return DISP_STATE_SEARCH_THREAD;
 		case NT_CMD_FAVORITE:
 			return DISP_STATE_FAVORITE;
+		case NT_CMD_HISTORY:
+			return DISP_STATE_HISTORY;
 		}
 	}
 
@@ -494,6 +497,11 @@ static int parse_cmd1(const char *param)
 		0 == strncmp(NT_COMMAND1_FAVORITE_2,param,
 			strlen(NT_COMMAND1_FAVORITE_2))){
 		return NT_CMD_FAVORITE;
+	}else if(0 == strncmp(NT_COMMAND1_HISTORY_1,param,
+			strlen(NT_COMMAND1_HISTORY_1)) ||
+		0 == strncmp(NT_COMMAND1_HISTORY_2,param,
+			strlen(NT_COMMAND1_HISTORY_2))){
+		return NT_CMD_HISTORY;
 	}else{
 		return NT_CMD_NONE;
 	}
