@@ -163,9 +163,12 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 		}
 	}
 	
-	if(prev_state != DISP_STATE_RESLIST &&
-		prev_state < NT_KEY_CMD_BASE)
+	if(prev_state == DISP_STATE_THREADTITLE ||
+		prev_state == DISP_STATE_SEARCH_THREAD ||
+		prev_state == DISP_STATE_FAVORITE ||
+		prev_state == DISP_STATE_HISTORY){
 		ctxp->prev_state = prev_state;
+	}
 
 	ch = wp->key;
 	result_state = DISP_STATE_RESLIST;
