@@ -147,8 +147,10 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 		wp->data = ctxp;
 		sort = TRUE;
 	}
-	if(prev_state != DISP_STATE_THREADTITLE)
+	if(prev_state == DISP_STATE_BOARDMENU ||
+		prev_state == DISP_STATE_FAVORITE){
 		ctxp->prev_state = prev_state;
+	}
 
 	h_board = nt_get_selected_board(h_select);
 	assert(h_board);
