@@ -30,6 +30,7 @@
 #include "utils/nt_std_t.h" 
 #include "utils/db.h" 
 #include "utils/text.h" 
+#include "utils/nt_mutex.h" 
 #include "utils/nt_conv_char.h" 
 #include "usr/usr_db_t.h" 
 
@@ -40,6 +41,7 @@ typedef struct tag_ctx_usr_db_t{
 	nt_usr_db_handle_t handle;
 	char db_path[PATH_MAX+1];
 	sqlite3 *dbp;
+	nt_mutex_handle h_mutex;
 }ctx_usr_db_t;
 
 static const char *NT_SQL_VALIDATE_USR_TBL =
@@ -97,6 +99,8 @@ static nt_usr_db_thread_data_tp
 		const wchar_t *dat_name, const wchar_t *board_name);
 static BOOL nt_remove_thread_data(nt_link_tp *thread_data,
 		const wchar_t *dat_name);
+static BOOL nt_usr_db_open(nt_usr_db_handle db_handle);
+static void nt_usr_db_close(nt_usr_db_handle db_handle);
 
 /* 
  * Initialize the Sqlite library.
@@ -121,6 +125,7 @@ nt_usr_db_handle nt_usr_db_init_lib(const char *db_path)
 	strcpy(ctxp->db_path, db_path);
 
 	ctxp->dbp = NULL;
+	ctxp->h_mutex = NULL;
 	ctxp->handle.chk_sum = NT_USR_DB_CHK_SUM;
 
 	if(!nt_usr_db_open(&ctxp->handle)){
@@ -130,6 +135,7 @@ nt_usr_db_handle nt_usr_db_init_lib(const char *db_path)
 	
 	ret = usr_tbl_validate(ctxp->dbp);
 	if(ret == -1){
+		nt_usr_db_close(&ctxp->handle);
 		nt_usr_db_finish_lib(&ctxp->handle);
 		return NULL;
 	}
@@ -162,10 +168,17 @@ BOOL nt_usr_db_open(nt_usr_db_handle db_handle)
 {
 	int rc;
 	ctx_usr_db_tp ctxp;
-
+	nt_mutex_handle h_mutex;
+	
 	assert(db_handle);
 	assert(db_handle->chk_sum == NT_USR_DB_CHK_SUM);
-
+	
+	h_mutex = nt_mutex_get_one_time_handle(L"usr_log_db:");
+	if(!h_mutex)
+		return FALSE;
+	if(!nt_mutex_lock(h_mutex))
+		return FALSE;
+	
 	ctxp = (ctx_usr_db_tp)db_handle;
 	rc = sqlite3_open_v2(ctxp->db_path, &ctxp->dbp,
 			SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE, NULL);
@@ -173,8 +186,10 @@ BOOL nt_usr_db_open(nt_usr_db_handle db_handle)
 		fputs(sqlite3_errmsg(ctxp->dbp), stderr);
 		sqlite3_close(ctxp->dbp);
 		ctxp->dbp = NULL;
+		nt_mutex_unlock(h_mutex);
 		return FALSE;
 	}
+	ctxp->h_mutex = h_mutex;
 	return TRUE;
 }
 
@@ -183,8 +198,11 @@ void nt_usr_db_close(nt_usr_db_handle db_handle)
 	assert(db_handle);
 	ctx_usr_db_tp ctxp = 
 		(ctx_usr_db_tp)db_handle;
+	assert(ctxp->h_mutex);
 	sqlite3_close(ctxp->dbp);
+	nt_mutex_unlock(ctxp->h_mutex);
 	ctxp->dbp = NULL;
+	ctxp->h_mutex = NULL;
 }
 
 int nt_usr_db_get_read_count_by_dat_name(
