@@ -500,15 +500,25 @@ nt_link_tp nt_link_next(nt_link_tp link)
 	return link->next;
 }
 
-nt_link_tp nt_link_copy(nt_link_tp src_linkp)
+nt_link_tp nt_link_copy(nt_link_tp src_linkp, nt_memcopy_fn copy_func)
 {
 	nt_link_tp srcp, resultp, workp;
+	void *ptr;
+	
 	assert(src_linkp);
 	
 	srcp = src_linkp;
 	resultp = NULL;
 	do{
-		workp = nt_link_add_data(resultp, srcp->data);
+		if(!copy_func){
+			workp = nt_link_add_data(resultp, srcp->data);
+		}else{
+			ptr = (copy_func)(srcp->data);
+			if(ptr)
+				workp = nt_link_add_data(resultp, ptr);
+			else
+				workp = NULL;
+		}
 		if(!workp){
 			if(resultp)
 				nt_all_link_free(resultp, NULL);
@@ -521,6 +531,31 @@ nt_link_tp nt_link_copy(nt_link_tp src_linkp)
 	return resultp;
 }
 
+void* nt_link_strcpy_fnc(void *ptr)
+{
+	char *cptr, *p;
+	int len;
+	cptr = (char*)ptr;
+	len = strlen(cptr);
+	p = malloc(len+1);
+	if(!p)
+		return NULL;
+	strcpy(p, cptr);
+	return p;
+}
+void* nt_link_wcscpy_fnc(void *ptr)
+{
+	wchar_t *cptr, *p;
+	int len;
+	cptr = (wchar_t*)ptr;
+	len = wcslen(cptr);
+	p = malloc((len+1)*sizeof(wchar_t));
+	if(!p)
+		return NULL;
+	wcscpy(p, cptr);
+	return p;
+}
+
 int nt_link_wcscmp_fnc(void *lhs, void *rhs)
 {
 	return wcscmp((const wchar_t *)lhs, (const wchar_t *)rhs);
